==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/ls/hls31_catalogextract.h <==
/*! 
  -----------------------------------------------------------------------------
 
  module: hls31_catalogextract.h
 
  -----------------------------------------------------------------------------
  responsible:  d033893 and SteffenS
  special area: Replication Manager
  description:  catalogextract
  version:      7.3

  -----------------------------------------------------------------------------
 
  copyright:    SAP AG, 2000-2002
 
  -----------------------------------------------------------------------------

   ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end
*/

#ifndef HLS31
#define HLS31

// Save Catalog

// Catalog Management
#include "gls00.h"

/*!
  -----------------------------------------------------------------------------
  function:     ls31ExecCatalogExtract
  -----------------------------------------------------------------------------

  description:  CatalogExtract main function

  arguments:    pDBInfo     [IN]    - A pointer to a structure that contains all 
                                      information on the running session and the
                                      database connected to.
                pCatExtrCmd [IN]    - A pointer to a structure that contains all
                                      information on the catalogextract command given
                                      by the user
                pszErrText  [OUT]   - error text

  returnvalue:  errOK_els00         - in case of NO errors
                some other errors   - in case of errors
  -----------------------------------------------------------------------------
*/
SAPDB_Int4
ls31ExecCatalogExtract(tls00_CatExtrCmd *pCatExtrCmd, tls00_DBInfo *pDBInfo, tsp00_Addr pszErrText);


/*!
  -----------------------------------------------------------------------------
  function:     ls31ExecCatalogLoad
  -----------------------------------------------------------------------------

  description:  CatalogLoad main function

  arguments:    pDBInfo     [IN]    - A pointer to a structure that contains all 
                                      information on the running session and the
                                      database connected to.
                pCatExtrCmd [IN]    - A pointer to a structure that contains all
                                      information on the catalogextract command given
                                      by the user
                pszErrText  [OUT]   - error text

  returnvalue:  errOK_els00         - in case of NO errors
                some other errors   - in case of errors
  -----------------------------------------------------------------------------
*/
SAPDB_Int4
ls31ExecCatalogLoad(tls00_CatLoadCmd *pCatLoadCmd, tls00_DBInfo *pDBInfo, tsp00_Addr pszErrText);

#endif /*HLS31*/

/*===========================================================================*
 *     END
 *===========================================================================*/

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/ls/hls31_catalogextract.h <==
/*! 
  -----------------------------------------------------------------------------
 
  module: hls30_catalogextract.h
 
  -----------------------------------------------------------------------------

  responsible:  d033893
  
  special area: SAP DB LOADER

  description:  catalogextract

  version:      7.5.

  -----------------------------------------------------------------------------
 
  copyright:    SAP AG, 1997-2000
 
  -----------------------------------------------------------------------------


     ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/

#ifndef HLS31
#define HLS31

// Save Catalog

// Catalog Management
#include "gls00.h"

/*!
  -----------------------------------------------------------------------------

  function:     ls31ExecCatalogTransformation

  -----------------------------------------------------------------------------

  description:  CatalogExtract main function

  arguments:    pDBInfo     [IN]    - A pointer to a structure that contains all 
                                      information on the running session and the
                                      database connected to.
				pTransformationCmd[IN]    
				                    - A pointer to a structure that contains all
                                      information on the catalogextract/catalogextract
									  command givenby the user
                errText     [OUT]   - A pointer to a buffer where a description is
                                      available in case of errors
  returnvalue:  errOK_els00         - in case of NO errors
                some other errors   - in case of errors

  -----------------------------------------------------------------------------
*/
SAPDB_Int4 ls31ExecCatalogTransformation( tls00_Command    *pTransformationCmd, 
								          tls00_DBInfo     *pDBInfo,
								          tsp00_Addr        ErrText);

tsp00_Int4 ls31LoadTransformationPackage ( MetaDataDef      *&pMetaDataDef,
                                           tls00_Command    *pTransformationCmd,
                                           tsp00_Addr        ErrText);

tsp00_Int4 ls31UpdateTransformationPackage( MetaDataDef     *pMetaDataDef,
										    tls00_Command   *pTransformationCmd,
										    tsp00_Addr       ErrText);   

tsp00_Int4 ls31UnloadTransformationPackage( MetaDataDef      *pMetaDataDef,
										    tls00_Command    *pTransformationCmd,
										    tsp00_Addr        ErrText); 

#endif /*HLS31*/

/*===========================================================================*
 *     END
 *===========================================================================*/
